@@ -72,8 +72,18 @@ createEffects <- function(effectGroup, xName=NULL, yName=NULL, zName = NULL,
 	effects
 }
 
+##@DoubleAttributesChecked utility function for getEffects
+DoubleAttributesChecked <- function(cova1, cova2)
+{
+	if (is.null(attr(cova1,"lowIntegers")) | is.null(attr(cova2,"lowIntegers")))
+	{
+		stop("Please use function sienaDataCreate for RSiena version at least 1.4.10")
+	}
+	(attr(cova1,"lowIntegers") && attr(cova2,"lowIntegers"))
+}
+
 ##@getEffects DataCreate create effects object
-getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeriodSde=FALSE)
+getEffects <- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeriodSde=FALSE)
 {
 	##@duplicateDataFrameRow internal getEffects Put period numbers in
 	duplicateDataFrameRow <- function(x, n)
@@ -186,6 +196,37 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 					symmetric, constant=TRUE, name=varname)
 				objEffects <-  rbind(objEffects, tmp$objEff)
 				rateEffects <- rbind(rateEffects, tmp$rateEff)
+
+				for (jj in seq(along = xx$cCovars))
+				{
+					if ((jj != j) && 
+					(DoubleAttributesChecked(xx$cCovars[[j]], xx$cCovars[[jj]])))
+					{
+						tmp <- doubleCovarNetEff(names(xx$cCovars)[j],
+						names(xx$cCovars)[jj], name=varname)
+						objEffects <-  rbind(objEffects, tmp$objEff)
+					}
+				}
+				for (jj in seq(along = xx$vCovars))
+				{
+					if (DoubleAttributesChecked(xx$cCovars[[j]], xx$vCovars[[jj]]))
+					{
+						tmp <- doubleCovarNetEff(names(xx$cCovars)[j],
+									names(xx$vCovars)[jj], name=varname)
+						objEffects <-  rbind(objEffects, tmp$objEff)
+					}		
+				}
+# I did not do the following, because it would lead to too many
+# unneeded effects. Keep it as an example of how it could be done.
+#				for (jj in seq(along = xx$depvars))
+#				{
+#					if (types[jj] =='behavior')
+#					{
+#						tmp <- doubleCovarNetEff(names(xx$cCovars)[j],
+#									names(xx$depvars)[jj], name=varname)
+#						objEffects <-  rbind(objEffects, tmp$objEff)
+#					}
+#				}
 			}
 		}
 		for (j in seq(along=xx$depvars))
@@ -202,7 +243,7 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 			}
 		}
 		for (j in seq(along=xx$vCovars))
-		{
+		{			
 			if (attr(xx$vCovars[[j]], 'nodeSet') == nodeSet)
 			{
 				tmp <- covarOneModeEff(names(xx$vCovars)[j],
@@ -294,7 +335,6 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 							otherName, name=varname,
 							groupName=groupName, group=group,
 							netType=netType))
-# The name "nonSymmetricBipartiteObjective"
 			}
 			if ((!(types[j] %in% c('behavior', 'continuous'))) && (varname != otherName))
 			{
@@ -352,6 +392,34 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 								group=group, netType=netType))
 					}
 				}
+				for (k in seq(along = xx$dycCovars))
+				{
+					nodset_j <- ifelse((attr(xx$depvars[[j]], "type") == "oneMode"), 
+								attr(xx$depvars[[j]], 'nodeSet'), attr(xx$depvars[[j]], 'nodeSet')[2])
+					if (attr(xx$dycCovars[[k]], 'nodeSet')[2] == nodset_j)
+					{
+						othervarname <- names(xx$dycCovars)[k]
+						objEffects <- rbind(objEffects,
+							createEffects("dyadBNetNetObjective",
+								varname, otherName, othervarname,
+								name=varname, groupName=groupName,
+								group=group, netType=netType))
+					}
+				}
+				for (k in seq(along = xx$dyvCovars))
+				{
+					nodset_j <- ifelse((attr(xx$depvars[[j]], "type") == "oneMode"), 
+								attr(xx$depvars[[j]], 'nodeSet'), attr(xx$depvars[[j]], 'nodeSet')[2])
+					if (attr(xx$dyvCovars[[k]], 'nodeSet')[2] == nodset_j)
+					{
+						othervarname <- names(xx$dyvCovars)[k]
+						objEffects <- rbind(objEffects,
+							createEffects("dyadBNetNetObjective",
+								varname, otherName, othervarname,
+								name=varname, groupName=groupName,
+								group=group, netType=netType))
+					}
+				}
 				for (k in seq(along=xx$depvars))
 				{
 					if ((types[k] %in% c('behavior', 'continuous')) &&
@@ -996,10 +1064,10 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 			if (attr(xx$dyvCovars[[j]], "type") == "oneMode" &&
 				(nodeSets[2] == attr(xx$dyvCovars[[j]], 'nodeSet')[1]) &&
 				(nodeSets[2] == attr(xx$dyvCovars[[j]], 'nodeSet')[2]) )
-			{
+			{ 
 				objEffects <- rbind(objEffects,
 					createEffects("dyadSecondBipartiteObjective",
-						names(xx$dycCovars)[j],
+						names(xx$dyvCovars)[j],
 						name=varname,
 						groupName=groupName, group=group,
 						netType=netType))
@@ -1018,7 +1086,29 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 						'moreThan2'),
 					covNodeset, name=varname)
 				objEffects <- rbind(objEffects, tmp$objEff)
-				rateEffects <- rbind(rateEffects, tmp$rateEff)
+				rateEffects <- rbind(rateEffects, tmp$rateEff)				
+				for (jj in seq(along = xx$cCovars))
+				{
+					if ((jj != j) & (nodeSets[1]==attr(xx$cCovars[[j]], "nodeSet"))
+									& (nodeSets[2]==attr(xx$cCovars[[jj]], "nodeSet"))
+							& (DoubleAttributesChecked(xx$cCovars[[j]], xx$cCovars[[jj]])))
+					{
+						tmp <- doubleCovarNetEff(names(xx$cCovars)[j],
+									names(xx$cCovars)[jj], name=varname)
+						objEffects <-  rbind(objEffects, tmp$objEff)
+					}
+				}
+				for (jj in seq(along = xx$vCovars))
+				{
+					if ((nodeSets[1]==attr(xx$cCovars[[j]], "nodeSet"))
+									& (nodeSets[2]==attr(xx$vCovars[[jj]], "nodeSet"))									
+							& (DoubleAttributesChecked(xx$cCovars[[j]], xx$vCovars[[jj]])))
+					{
+						tmp <- doubleCovarNetEff(names(xx$cCovars)[j],
+									names(xx$vCovars)[jj], name=varname)
+						objEffects <-  rbind(objEffects, tmp$objEff)
+					}
+				}						
 			}
 		}
 		for (j in seq(along=xx$depvars))
@@ -1131,6 +1221,34 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 									netType=netType))
 					}
 				}
+				for (k in seq(along = xx$dycCovars))
+				{
+					nodset_j <- ifelse((attr(xx$depvars[[j]], "type") == "oneMode"), 
+								attr(xx$depvars[[j]], 'nodeSet'), attr(xx$depvars[[j]], 'nodeSet')[2])
+					if (attr(xx$dycCovars[[k]], 'nodeSet')[2] == nodset_j)
+					{
+						othervarname <- names(xx$dycCovars)[k]
+						objEffects <- rbind(objEffects,
+							createEffects("dyadBNetNetObjective",
+								varname, otherName, othervarname,
+								name=varname, groupName=groupName,
+								group=group, netType=netType))
+					}
+				}
+				for (k in seq(along = xx$dyvCovars))
+				{
+					nodset_j <- ifelse((attr(xx$depvars[[j]], "type") == "oneMode"), 
+								attr(xx$depvars[[j]], 'nodeSet'), attr(xx$depvars[[j]], 'nodeSet')[2])
+					if (attr(xx$dyvCovars[[k]], 'nodeSet')[2] == nodset_j)
+					{
+						othervarname <- names(xx$dyvCovars)[k]
+						objEffects <- rbind(objEffects,
+							createEffects("dyadBNetNetObjective",
+								varname, otherName, othervarname,
+								name=varname, groupName=groupName,
+								group=group, netType=netType))
+					}
+				}
 				for (k in seq(along=xx$depvars))
 				{
 					if (types[k] %in% c('behavior', 'continuous') &&
@@ -1213,7 +1331,7 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 				groupName=groupName, group=group,
 				netType=netType)
 		}
-
+				
 		if (constant)
 		{
 			covObjEffects <-
@@ -1245,6 +1363,18 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 
 		list(objEff=covObjEffects, rateEff=covRateEffects)
 	}
+	
+	##@doubleCovarNetEff internal getEffects
+	doubleCovarNetEff<- function(covarname1, covarname2, name)
+	{
+		covObjEffects <- createEffects("doubleCovarNetObjective", 
+				covarname1,covarname2,
+				name=name,
+				groupName=groupName, group=group,
+				netType=netType)
+		list(objEff=covObjEffects, rateEff=NULL)
+	}
+	
 	##@covarBipartiteEff internal getEffects
 	covarBipartiteEff<- function(covarname, poszvar, moreThan2, nodesetNbr,
 		name)
@@ -1257,10 +1387,10 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 					name=varname,
 					groupName=groupName, group=group,
 					netType=netType)
-			# restrict to covariates on first node set
+			# restrict to covariates on first node set, but also include sameX
 			covObjEffects <-
 				covObjEffects[covObjEffects$shortName %in%
-				c("egoX", "egoSqX", "egoLThresholdX", "egoRThresholdX",
+				c("egoX", "egoSqX", "sameX", "egoLThresholdX", "egoRThresholdX",
 					"degAbsDiffX", "degPosDiffX", "degNegDiffX",
 					"altInDist2", "totInDist2", "simEgoInDist2", 
 					"sameEgoInDist2", "sameXInPop", "diffXInPop",
@@ -1280,8 +1410,8 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE, onePeri
 			covObjEffects <-
 				covObjEffects[covObjEffects$shortName %in%
 				c("altX", "altSqX",  "altLThresholdX", "altRThresholdX",
-					"homXOutAct", "altXOutAct",
-					"inActX", "outActX"), ]
+					"homXOutAct", "homXOutAct2", "altXOutAct",
+					"inActX", "outActX", "sameInXCycle4"), ]
 			if (!tr & (!moreThan2))
 			{
 				covObjEffects <-
