@@ -78,6 +78,7 @@ effectsDocumentation <- function(effects= NULL, type="html",
 				"dyadANetNetObjective",
 				"covarABipNetObjective",
 				"dyadANetNetObjective",
+				"dyadBNetNetObjective",
 				"settingsObjective",
 
 				"symmetricObjective",
@@ -87,6 +88,7 @@ effectsDocumentation <- function(effects= NULL, type="html",
 				"dyadBipartiteObjective",
 				"dyadSecondBipartiteObjective",
 				"covarBipartiteObjective",
+				"doubleCovarNetObjective", 
 				"unspecifiedNetInteraction",
 				"bipartiteNonSymmetricObjective",
 				"bipartiteSymmetricObjective",
