@@ -10,8 +10,8 @@
 ## *
 ## ****************************************************************************/
 ##@print.sienaEffects Methods
-print.sienaEffects <- function(x, fileName=NULL, includeOnly=TRUE,
-    expandDummies=FALSE, includeRandoms=FALSE, dropRates=FALSE, ...)
+print.sienaEffects <- function(x, fileName=NULL, includeOnly=TRUE, 
+    expandDummies=FALSE, includeRandoms=FALSE, dropRates=FALSE, includeShortNames=FALSE, ...)
 {
     if (!inherits(x, "sienaEffects"))
         stop("not a legitimate Siena effects object")
@@ -21,7 +21,7 @@ print.sienaEffects <- function(x, fileName=NULL, includeOnly=TRUE,
         sink(fileName, split=TRUE)
     }
 
-    interactions <- x[x$shortName %in% c("unspInt", "behUnspInt") & x$include &
+    interactions <- x[x$shortName %in% c("unspInt", "behUnspInt", "contUnspInt") & x$include &
         x$effect1 > 0, ]
     if (expandDummies)
     {
@@ -29,13 +29,13 @@ print.sienaEffects <- function(x, fileName=NULL, includeOnly=TRUE,
             || !all(x[, "timeDummy"] == "," ))
         {
             x <- sienaTimeFix(x)$effects
-            x <- fixUpEffectNames(x)
+#            x <- fixUpEffectNames(x)
         }
         else
         {
             if (nrow(interactions) > 0)
             {
-                x <- fixUpEffectNames(x)
+#                x <- fixUpEffectNames(x)
             }
         }
     }
@@ -43,13 +43,22 @@ print.sienaEffects <- function(x, fileName=NULL, includeOnly=TRUE,
     {
         nDependents <- length(unique(x$name))
         userSpecifieds <- x$shortName[x$include] %in%
-            c("unspInt", "behUnspInt")
+            c("unspInt", "behUnspInt", "contUnspInt")
         endowments <- !x$type[x$include] %in% c("rate", "eval", "gmm")
         # includes creations and gmm
         gmm <- any(x$type[x$include] %in% "gmm")
         timeDummies <- !x$timeDummy[x$include] == ","
-        specs <- as.data.frame(x[, c("name", "effectName", "include", "fix",
+		if (includeShortNames)
+		{
+			specs <- as.data.frame(x[, c("effectNumber", "name", "effectName", 
+				"shortName", "include", "fix",
+                "test", "initialValue", "parm")])	
+		}
+		else
+		{
+			specs <- as.data.frame(x[, c("name", "effectName", "include", "fix",
                 "test", "initialValue", "parm")])
+		}
         if (includeOnly)
         {
             included <- x$include
@@ -69,7 +78,8 @@ print.sienaEffects <- function(x, fileName=NULL, includeOnly=TRUE,
         }
         if (nDependents == 1)
         {
-            specs <- specs[, -1]  # drop name of dependent variable
+			whichname <- which(names(specs)=="name")
+            specs <- specs[, -whichname]  # drop name of dependent variable
         }
         if (any(endowments))
         {
@@ -231,19 +241,21 @@ edit.sienaEffects <- function(name, ...)
     ## re-sort the columns
     tmp <- tmp[, match(originalNames, names(tmp))]
     class(tmp) <- c("sienaEffects", class(tmp))
+	 attr(tmp, "version") <- packageDescription(pkgname, fields = "Version")
     tmp
 }
 
 ##@updateSpecification Methods add specified effects from other effects object
-updateSpecification <- function(effects.to, effects.from, name.to=NULL, name.from=NULL)
+updateSpecification <- function(effects.to, effects.from,
+									effects.extra=NULL, name.to=NULL, name.from=NULL)
 {
-    if (!inherits(effects.to, "data.frame"))
+    if (!inherits(effects.to, "sienaEffects"))
     {
-        stop("effects.to is not a data.frame")
+        stop("effects.to is not an effects object")
     }
-    if (!inherits(effects.from, "data.frame"))
+    if (!inherits(effects.from, "sienaEffects"))
     {
-        stop("effects.from is not a data.frame")
+        stop("effects.from is not an effects object")
     }
     if (is.null(name.from))
     {
@@ -308,5 +320,136 @@ updateSpecification <- function(effects.to, effects.from, name.to=NULL, name.fro
     effects.to$test[use] <- prevEffects$test[correspondence][use]
     effects.to$parm[use] <- prevEffects$parm[correspondence][use]
     effects.to$randomEffects[use] <- prevEffects$randomEffects[correspondence][use]
+    effects.to$initialValue[use] <- prevEffects$initialValue[correspondence][use]
+# the above does not transfer interaction effects.
+# A lot of work is needed to get the information about the interacting effects.
+    inter <- which(prevEffects$include &
+						(prevEffects$shortName %in% c("unspInt","behUnspInt","contUnspInt")))
+    if (length(inter) >= 1)
+	{
+	# look up the interacting main effects, and try to get information
+	# about which are the interacting effects.
+	    cat("Handling interactions ... ")
+		efn1 <- prevEffects$effect1[inter]
+		efn2 <- prevEffects$effect2[inter]
+		efn3 <- prevEffects$effect3[inter]
+	# prepare a stopmessage; this will possibly be used at various places.
+		if (is.null(effects.extra))
+		{
+			stopMessage <- paste("Effects object ", deparse(substitute(effects.from)),
+					" contains some interactions \n",
+					" but there is no information ",
+					"for the corresponding main effects.", sep="")
+		}
+		else
+		{
+			stopMessage <- paste("Effects object ", deparse(substitute(effects.from)),
+					" contains some interactions \n",
+					"  and neither this nor ", deparse(substitute(effects.extra)),
+					"\n contains information for the corresponding main effects.", sep="")
+		}
+	# Note that some of efn3 may be 0,
+	# and effects.from$effectNumber starts counting from 1.
+	# First try to find the corresponding main effects in effects.from
+		three <- (efn3 > 0)
+		mefn1 <- match(efn1, effects.from$effectNumber)
+		mefn2 <- match(efn2, effects.from$effectNumber)
+		mefn3 <- ifelse(three, match(efn3, effects.from$effectNumber), 0)
+		effects.fr <- effects.from
+		if (any(is.na(c(mefn1,mefn2,mefn3))))
+		{
+			if (is.null(effects.extra))
+			{
+				stop("Effects object ", deparse(substitute(effects.from)),
+					" contains some interactions \n",
+					"  without information for the corresponding main effects,\n",
+					"  and there is no effects.extra.")
+			}
+			else
+			{
+				if (!inherits(effects.extra, "sienaEffects"))
+				{
+					stop("effects.extra is needed, and is not an effects object")
+				}
+	# Now try to find the corresponding main effects in effects.extra
+				version1 <- attr(effects.from, "version")
+				version2 <- attr(effects.extra, "version")
+				sameversion <- FALSE
+				if ((!is.null(version1)) & (!is.null(version2)))
+				{
+					sameversion <- (version1==version2)
+				}
+				if (!sameversion)
+				{
+					warning("RSiena versions of effects.from and effects.extra",
+						" are different;\n",
+						"  check that the effects object",
+						" generated by updateSpecification is correct.")
+				}
+				mefn1 <- match(efn1, effects.extra$effectNumber)
+				mefn2 <- match(efn2, effects.extra$effectNumber)
+				mefn3 <- ifelse(three, match(efn3, effects.extra$effectNumber), 0)
+				if (any(is.na(c(mefn1,mefn2,mefn3))))
+				{
+					stop(stopMessage)
+				}
+				effects.fr <- effects.extra
+			}
+		}
+        shn1  <- effects.fr[mefn1,"shortName"]
+        shn2  <- effects.fr[mefn2,"shortName"]
+		shn3  <- rep('', length(three))
+        shn3[three]  <- effects.fr[mefn3[three],"shortName"]
+        int11  <- effects.fr[mefn1,"interaction1"]
+        int12  <- effects.fr[mefn2,"interaction1"]
+		int13  <- rep('', length(three))
+        int13[three]  <- effects.fr[mefn3[three],"interaction1"]
+        int21  <- effects.fr[mefn1,"interaction2"]
+        int22  <- effects.fr[mefn2,"interaction2"]
+		int23  <- rep('', length(three))
+        int23[three]  <- effects.fr[mefn3[three],"interaction2"]
+        nam  <- prevEffects[inter,"name"]
+        typ   <- prevEffects[inter,"type"]
+        fixx  <- prevEffects[inter,"fix"]
+        tests <- prevEffects[inter,"test"]
+        rand  <- prevEffects[inter,"randomEffects"]
+		initv <- prevEffects[inter,"initialValue"]
+#browser()
+        for (k in seq_along(inter)){
+			cat(k," ")
+			flush.console()
+			if (three[k])
+			{
+				if (inherits(try(
+						effects.to <- includeInteraction(effects.to, shn1[k], shn2[k], shn3[k],
+						name=nam[k],
+						interaction1=c(int11[k],int12[k],int13[k]),
+						interaction2=c(int21[k],int22[k],int23[k]),
+						initialValue=initv[k],
+						type=typ[k], fix=fixx[k], test=tests[k], random=rand[k],
+						verbose=FALSE, character=TRUE), 
+					silent=TRUE), "try-error"))
+				{
+					stop(stopMessage)
+				}
+			}
+			else
+			{
+				if (inherits(try(
+					effects.to <- includeInteraction(effects.to, shn1[k], shn2[k],
+						name=nam[k],
+						interaction1=c(int11[k],int12[k]),
+						interaction2=c(int21[k],int22[k]),
+						initialValue=initv[k],
+						type=typ[k], fix=fixx[k], test=tests[k], random=rand[k],
+						verbose=FALSE, character=TRUE), 
+					silent=TRUE), "try-error"))
+				{
+					stop(stopMessage)
+				}
+			}
+        }
+		cat("\n")
+    }
     effects.to
 }
