@@ -446,6 +446,15 @@ int NetworkLongitudinalData::modelType() const
 	return this->lmodelType;
 }
 
+/**
+ * Returns whether the model type is NETCONTEMP.
+ */
+bool NetworkLongitudinalData::networkModelTypeContemp() const
+{
+	// This uses the order specified in 
+	// enum NetworkModelType in DependentVariable.h
+	return (this->lmodelType==11);
+}
 /**
  * Stores the average in-degree over all receivers and observations.
  */
