@@ -15,7 +15,6 @@
 #include <R_ext/Error.h>
 #include <R_ext/Print.h>
 #include <R_ext/Arith.h>
-#include <Rinternals.h>
 #include "SdeSimulation.h"
 #include "EpochSimulation.h"
 #include "utils/Random.h"
@@ -41,6 +40,7 @@
 #include "model/filters/LowerFilter.h"
 #include "model/ml/Chain.h"
 #include "model/ml/MiniStep.h"
+#include <Rinternals.h>
 
 using namespace std;
 
@@ -344,7 +344,7 @@ void EpochSimulation::runEpoch(int period) {
 				exit(1);
 #endif
 #ifndef STANDALONE
-				error("%s %s", "Unlikely to terminate this epoch:",
+				Rf_error("%s %s", "Unlikely to terminate this epoch:",
 						" more than 1000000 steps");
 #endif
 			}
@@ -356,7 +356,7 @@ void EpochSimulation::runEpoch(int period) {
 				exit(1);
 #endif
 #ifndef STANDALONE
-				error("%s %s", "Unlikely to terminate this epoch:",
+				Rf_error("%s %s", "Unlikely to terminate this epoch:",
 						" more than 1000000 steps");
 #endif
 			}
@@ -634,7 +634,7 @@ void EpochSimulation::updateContinuousVariablesAndScores() {
 	// up to now only for one continuous variable
 	// function is never called if lcontVar's.size() == 0
 	if (this->lcontinuousVariables.size() > 1) {
-		error("EpochSimulation: Not more than one continuous variable.");
+		Rf_error("EpochSimulation: Not more than one continuous variable.");
 	}
 
 	ContinuousVariable * pVariable = this->lcontinuousVariables[0];
@@ -874,7 +874,7 @@ double EpochSimulation::calculateLikelihood() const {
 		sumLogChoiceProbabilities += pMiniStep->logChoiceProbability();
 		//	if (!R_finite(pMiniStep->logChoiceProbability()))
 		//{
-		//		PrintValue(getMiniStepDF(*pMiniStep));
+		//		Rf_PrintValue(getMiniStepDF(*pMiniStep));
 		//	Rprintf(" epcoh %f %f\n", pMiniStep->logOptionSetProbability(),
 		//	pMiniStep->logChoiceProbability() );
 		//}
