@@ -5,9 +5,14 @@
 #include "network/Network.h"
 #include "data/NetworkLongitudinalData.h"
 #include "data/BehaviorLongitudinalData.h"
+#include "data/ContinuousLongitudinalData.h"
 #include "model/EpochSimulation.h"
 #include "model/variables/NetworkVariable.h"
 #include "model/variables/BehaviorVariable.h"
+#include "model/variables/ContinuousVariable.h"
+#include "model/settings/Setting.h"
+#include "model/settings/PrimarySetting.h"
+#include "network/OneModeNetwork.h"
 
 using namespace std;
 
@@ -30,6 +35,8 @@ State::State(const Data * pData, int observation, bool ownedValues)
 			dynamic_cast<NetworkLongitudinalData *>(rVariables[i]);
 		BehaviorLongitudinalData * pBehaviorData =
 			dynamic_cast<BehaviorLongitudinalData *>(rVariables[i]);
+		ContinuousLongitudinalData * pContinuousData =
+			dynamic_cast<ContinuousLongitudinalData *>(rVariables[i]);
 
 		if (pNetworkData)
 		{
@@ -60,9 +67,42 @@ State::State(const Data * pData, int observation, bool ownedValues)
 
 			this->lbehaviors[pBehaviorData->name()] = values;
 		}
+		else if (pContinuousData)
+		{
+			const double * values = pContinuousData->values(observation);
+
+			if (ownedValues)
+			{
+				double * copies = new double[pContinuousData->n()];
+
+				for (int actor = 0; actor < pContinuousData->n(); actor++)
+				{
+					copies[actor] = values[actor];
+				}
+
+				values = copies;
+			}
+
+			this->lcontinuous[pContinuousData->name()] = values;
+		}
 		else
 		{
-			throw domain_error("Unexpected class of longitudinal data");
+			throw domain_error("unexpected class for longitudinal data: " + rVariables[i]->name());
+		}
+	}
+
+	// SimVariables!
+	const vector<LongitudinalData *> & rSimVariables = pData->rSimVariableData();
+	for (unsigned i = 0; i < rSimVariables.size(); i++) {
+		NetworkLongitudinalData * pNetworkData = dynamic_cast<NetworkLongitudinalData *>(rSimVariables[i]);
+		if (pNetworkData) {
+			const Network * pNetwork = pNetworkData->pNetwork(observation);
+			if (ownedValues) {
+				pNetwork = pNetwork->clone();
+			}
+			this->lnetworks[pNetworkData->name()] = pNetwork;
+		} else {
+			throw domain_error("unexpected class for simulated data: " + rSimVariables[i]->name());
 		}
 	}
 
@@ -72,9 +112,7 @@ State::State(const Data * pData, int observation, bool ownedValues)
 
 State::State(EpochSimulation * pSimulation)
 {
-	const vector<DependentVariable *> & rVariables =
-		pSimulation->rVariables();
-
+	const vector<DependentVariable *> & rVariables = pSimulation->rVariables();
 	for (unsigned i = 0; i < rVariables.size(); i++)
 	{
 		NetworkVariable * pNetworkVariable =
@@ -86,6 +124,16 @@ State::State(EpochSimulation * pSimulation)
 		{
 			this->lnetworks[pNetworkVariable->name()] =
 				pNetworkVariable->pNetwork();
+
+			const Setting * pSetting = pNetworkVariable->setting(1); // 0=universal, 1=primary
+			if (pSetting) {
+				const PrimarySetting * pPSetting = dynamic_cast<const PrimarySetting *>(pSetting);
+				if (pPSetting) {
+					if (pPSetting->pPrimaryNetwork() == 0) throw domain_error("no setting");
+					std::string pname = "primary(" + pNetworkVariable->name() + ")";
+					this->lnetworks[pname] = pPSetting->pPrimaryNetwork();
+				}
+			}
 		}
 		else if (pBehaviorVariable)
 		{
@@ -94,10 +142,19 @@ State::State(EpochSimulation * pSimulation)
 		}
 		else
 		{
-			throw domain_error("Unexpected class of dependent variable");
+			throw domain_error("unexpected class for dependent variable: " + rVariables[i]->name());
 		}
 	}
 
+	const vector<ContinuousVariable *> & rContinuousVariables =
+		pSimulation->rContinuousVariables();
+
+	for (unsigned i = 0; i < rContinuousVariables.size(); i++)
+	{
+		this->lcontinuous[rContinuousVariables[i]->name()] =
+				rContinuousVariables[i]->values();
+	}
+
 	this->lownedValues = false;
 }
 
@@ -177,6 +234,34 @@ void State::behaviorValues(string name, const int * values)
 }
 
 
+/**
+ * Returns the values of the continuous behavior variable with the given
+ * name, or 0 if no such values are stored in this state.
+ */
+const double * State::continuousValues(string name) const
+{
+	const double * values = 0;
+	map<string, const double *>::const_iterator iter =
+		this->lcontinuous.find(name);
+
+	if (iter != this->lcontinuous.end())
+	{
+		values = iter->second;
+	}
+
+	return values;
+}
+
+
+/**
+ * Stores the values of a continuous behavior variable with the given name.
+ */
+void State::continuousValues(string name, const double * values)
+{
+	this->lcontinuous[name] = values;
+}
+
+
 /**
  * Deletes the values stored in this state (only called if lownedValues).
  */
@@ -200,6 +285,13 @@ void State::deleteValues()
 		this->lbehaviors.erase(this->lbehaviors.begin());
 		delete[] values;
 	}
+
+	while (!this->lcontinuous.empty())
+	{
+		const double * values = this->lcontinuous.begin()->second;
+		this->lcontinuous.erase(this->lcontinuous.begin());
+		delete[] values;
+	}
 }
 
 }
