@@ -37,7 +37,9 @@
 #include "BehaviorInteractionEffect.h"
 #include "BetweennessEffect.h"
 #include "BothDegreesEffect.h"
+#include "CatCovariateActivityEffect.h"
 #include "ConstantEffect.h"
+#include "ContinuousInteractionEffect.h"
 #include "CovariateAlterEffect.h"
 #include "CovariateContrastEffect.h"
 #include "CovariateDiffEffect.h"
@@ -49,6 +51,7 @@
 #include "CovariateIndirectTiesEffect.h"
 #include "CovariateSimilarityEffect.h"
 #include "CovariateTransitiveTripletsEffect.h"
+#include "CrossCovariateActivityEffect.h"
 #include "DenseTriadsBehaviorEffect.h"
 #include "DenseTriadsEffect.h"
 #include "DenseTriadsSimilarityEffect.h"
@@ -96,6 +99,7 @@
 #include "OutdegreeActivitySqrtEffect.h"
 #include "OutdegreePopularityEffect.h"
 #include "OutInDegreeAssortativityEffect.h"
+#include "OutIndegreeBalanceContinuousEffect.h"
 #include "OutOutDegreeAssortativityEffect.h"
 #include "PopularityAlterEffect.h"
 #include "PrimarySettingEffect.h"  
@@ -110,6 +114,7 @@
 #include "SameCovariateEffect.h"
 #include "SameCovariateActivityEffect.h"
 #include "SameCovariateFourCyclesEffect.h"
+#include "SameInCovariateFourCyclesEffect.h"
 #include "SettingSizeEffect.h"
 #include "SameCovariateTransitiveTripletsEffect.h"
 #include "HomCovariateTransitiveTripletsEffect.h"
@@ -128,6 +133,8 @@
 #include "TransitiveTripletsEffect.h"
 #include "TruncatedOutdegreeEffect.h"
 #include "TruncatedOutXEffect.h"
+#include "VarianceAlterEffect.h"
+#include "VarianceAlterSimilarityEffect.h"
 #include "WienerEffect.h"
 #include "WWXClosureEffect.h"
 #include "WXXClosureEffect.h"
