@@ -37,17 +37,17 @@ public:
 private:
 	int denseTriadCount(int i);
 
-	int ldensity;
+	int ldensity {};
 
 	// A helper array of marks for counting dense triads
-	int * lmark;
+	int * lmark {};
 
 	// Given an ego i
 	// mark[h] = baseMark + 2 if there are mutual ties between i and h,
 	// mark[h] = baseMark + 1 if only one of the mutual ties is present,
 	// mark[h] <= baseMark otherwise.
 
-	int lbaseMark;
+	int lbaseMark {};
 };
 
 }
