@@ -25,6 +25,7 @@
 #include "model/effects/generic/ConstantFunction.h"
 #include "model/effects/generic/InDegreeFunction.h"
 #include "model/effects/generic/IntSqrtFunction.h"
+#include "model/effects/generic/IntLogFunction.h"
 #include "model/effects/generic/DifferenceFunction.h"
 #include "model/effects/generic/AbsDiffFunction.h"
 #include "model/effects/generic/SumFunction.h"
@@ -46,9 +47,12 @@
 #include "model/effects/generic/TwoStepFunction.h"
 #include "model/effects/generic/ReverseTwoPathFunction.h"
 #include "model/effects/generic/MixedTwoStepFunction.h"
+#include "model/effects/generic/MixedThreePathFunction.h"
 #include "model/effects/generic/WeightedMixedTwoPathFunction.h"
 #include "model/effects/generic/ConditionalFunction.h"
 #include "model/effects/generic/EqualCovariatePredicate.h"
+#include "model/effects/generic/DoubleEqualCovariateFunction.h"
+#include "model/effects/generic/DoubleCovariateCatFunction.h"
 #include "model/effects/generic/MissingCovariatePredicate.h"
 #include "model/effects/generic/DoubleOutActFunction.h"
 #include "model/effects/generic/CovariateDistance2AlterNetworkFunction.h"
@@ -68,8 +72,12 @@
 #include "model/effects/generic/DifferentCovariateOutStarFunction.h"
 #include "model/effects/generic/HomCovariateMixedTwoPathFunction.h"
 #include "model/effects/generic/OutActDistance2Function.h"
+#include "model/effects/generic/OutActDoubleDistance2Function.h"
+#include "model/effects/generic/DegreeDistance2Function.h"
 #include "model/effects/generic/MixedThreeCyclesFunction.h"
+#include "model/effects/generic/MixedDyadicCovThreeCyclesFunction.h"
 #include "model/effects/generic/InStarsTimesDegreesFunction.h"
+#include "model/effects/generic/IndirectTiesFunction.h"
 #include "model/tables/EgocentricConfigurationTable.h"
 #include "model/tables/NetworkCache.h"
 
@@ -127,6 +135,10 @@ map<const string, const string> EffectFactory::init_groups() {
 	map.insert(make_pair("totAlt_gmm", "totAlt"));
 	map.insert(make_pair("maxAlt_gmm", "maxAlt"));
 	map.insert(make_pair("minAlt_gmm", "minAlt"));
+	//
+	map.insert(make_pair("crprod_gmm", "crpod"));
+	map.insert(make_pair("from_gmm", "from"));
+	map.insert(make_pair("to_gmm", "to"));
 	return map;
 }
 
@@ -174,6 +186,8 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			dynamic_cast<NetworkEffect *>(pEffect1);
 		BehaviorEffect * pBehaviorEffect1 =
 			dynamic_cast<BehaviorEffect *>(pEffect1);
+        ContinuousEffect * pContinuousEffect1 =
+            dynamic_cast<ContinuousEffect *>(pEffect1);
 
 		if (pNetworkEffect1)
 		{
@@ -189,7 +203,7 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 				pNetworkEffect2,
 				pNetworkEffect3);
 		}
-		else
+		else if (pBehaviorEffect1)
 		{
 			BehaviorEffect * pBehaviorEffect2 =
 				dynamic_cast<BehaviorEffect *>(pEffect2);
@@ -204,6 +218,22 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 				pBehaviorEffect2,
 				pBehaviorEffect3);
 		}
+        else
+        {
+            ContinuousEffect * pContinuousEffect2 =
+                dynamic_cast<ContinuousEffect *>(pEffect2);
+            ContinuousEffect * pContinuousEffect3 = 0;
+            if (pEffect3)
+            {
+                pContinuousEffect3 = dynamic_cast<ContinuousEffect *>(pEffect3);
+            }
+
+            pEffect = new ContinuousInteractionEffect(pEffectInfo,
+                pContinuousEffect1,
+                pContinuousEffect2,
+                pContinuousEffect3);
+        }
+
 	}
 	else if (effectName == "density")
 	{
@@ -366,27 +396,35 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "outTrunc")
 	{
-		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, false);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, false, false);
 	}
 	else if (effectName == "outTrunc2")
 	{
-		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, false);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, false, false);
 	}
 	else if (effectName == "outMore")
 	{
-		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false, false);
 	}
 	else if (effectName == "outMore2")
 	{
-		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false, false);
 	}
 	else if (effectName == "outMore3")
 	{
-		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false, false);
 	}
 	else if (effectName == "outIso")
 	{
-		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, true);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, true, false);
+	}
+	else if (effectName == "outThreshold")
+	{
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false, true);
+	}
+	else if (effectName == "outThreshold2")
+	{
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false, true);
 	}
 	else if (effectName == "outInv")
 	{
@@ -620,13 +658,47 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new SameCovariateEffect(pEffectInfo, true, false);
 	}
+	else if (effectName == "sameXV")
+	{
+		string covariateName1 = pEffectInfo->interactionName1();
+		string covariateName2 = pEffectInfo->interactionName2();
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new DoubleEqualCovariateFunction(covariateName1, covariateName2, false),
+			new DoubleEqualCovariateFunction(covariateName1, covariateName2, true));
+	}
+	else if (effectName == "sameXVInPop")
+	{
+		string networkName = pEffectInfo->variableName();
+		string covariateName1 = pEffectInfo->interactionName1();
+		string covariateName2 = pEffectInfo->interactionName2();
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new DoubleCovariateCatFunction(covariateName1, covariateName2,
+				networkName, pEffectInfo->internalEffectParameter(), false, false),
+			new DoubleCovariateCatFunction(covariateName1, covariateName2,
+				networkName, pEffectInfo->internalEffectParameter(), true, false));
+	}
+	else if (effectName == "sameXVInPop2")
+	{
+		string networkName = pEffectInfo->variableName();
+		string covariateName1 = pEffectInfo->interactionName1();
+		string covariateName2 = pEffectInfo->interactionName2();
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new DoubleCovariateCatFunction(covariateName1, covariateName2,
+				networkName, pEffectInfo->internalEffectParameter(), false, true),
+			new DoubleCovariateCatFunction(covariateName1, covariateName2,
+				networkName, pEffectInfo->internalEffectParameter(), true, true));
+	}
 	else if (effectName == "unequalX")
 	{
 		pEffect = new SameCovariateEffect(pEffectInfo, false, false);
 	}
 	else if (effectName == "higher")
 	{
-		pEffect = new HigherCovariateEffect(pEffectInfo);
+		pEffect = new HigherCovariateEffect(pEffectInfo, false);
+	}
+	else if (effectName == "altHigherEgoX")
+	{
+		pEffect = new HigherCovariateEffect(pEffectInfo,true);
 	}
 	else if (effectName == "sameXRecip")
 	{
@@ -696,15 +768,13 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		string networkName = pEffectInfo->variableName();
 		string covariateName = pEffectInfo->interactionName1();
+		int parameter = int(round(pEffectInfo->internalEffectParameter()));
 		AlterFunction * pChangeFunction =
-			new SameCovariateInTiesFunction(networkName, covariateName, true, true, false);
+			new SameCovariateInTiesFunction(networkName, covariateName, 
+													true, true, parameter, false);
 		AlterFunction * pStatisticFunction =
-			new SameCovariateInTiesFunction(networkName, covariateName, true, true, true);
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
+			new SameCovariateInTiesFunction(networkName, covariateName, 
+													true, true, parameter, true);
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			pChangeFunction, pStatisticFunction);
 	}
@@ -712,15 +782,13 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		string networkName = pEffectInfo->variableName();
 		string covariateName = pEffectInfo->interactionName1();
+		int parameter = int(round(pEffectInfo->internalEffectParameter()));
 		AlterFunction * pChangeFunction =
-			new SameCovariateInTiesFunction(networkName, covariateName, false, true, false);
+			new SameCovariateInTiesFunction(networkName, covariateName, 
+												false, true, parameter, false);	
 		AlterFunction * pStatisticFunction =
-			new SameCovariateInTiesFunction(networkName, covariateName, false, true, true);
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
+			new SameCovariateInTiesFunction(networkName, covariateName, 
+												false, true, parameter, true);
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			pChangeFunction, pStatisticFunction);
 	}
@@ -732,10 +800,18 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new SameCovariateActivityEffect(pEffectInfo, false, false);
 	}
+	else if (effectName == "crossXOutAct")
+	{
+		pEffect = new CrossCovariateActivityEffect(pEffectInfo, false);
+	}
 	else if (effectName == "homXOutAct")
 	{
 		pEffect = new HomCovariateActivityEffect(pEffectInfo, true);
 	}
+	else if (effectName == "homXOutAct2")
+	{
+		pEffect = new CatCovariateActivityEffect(pEffectInfo);
+	}
 	else if (effectName == "altXOutAct")
 	{
 		pEffect = new AlterCovariateActivityEffect(pEffectInfo);
@@ -774,7 +850,11 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "sameXCycle4")
 	{
-		pEffect = new SameCovariateFourCyclesEffect(pEffectInfo, true);
+		pEffect = new SameCovariateFourCyclesEffect(pEffectInfo);
+	}
+	else if (effectName == "sameInXCycle4")
+	{
+		pEffect = new SameInCovariateFourCyclesEffect(pEffectInfo);
 	}
 	else if (effectName == "avGroupEgoX")
 	{
@@ -782,15 +862,16 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "cycle4")
 	{
-		pEffect = new FourCyclesEffect(pEffectInfo, true);
+		pEffect = new FourCyclesEffect(pEffectInfo);
 	}
 	else if (effectName == "sharedPop")
 	{
-		pEffect = new FourCyclesEffect(pEffectInfo, false);
+		pEffect = new FourCyclesEffect(pEffectInfo);
 	}
 	else if (effectName == "cycle4ND")
-	{
-		pEffect = new FourCyclesEffect(pEffectInfo, false);
+	{		
+		throw domain_error(
+	"effect shortName cycle4ND replaced by cycle4; please change your code");
 	}
 	else if ((effectName == "gwespFF")||(effectName == "gwesp"))
 	{
@@ -874,6 +955,11 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new OutTieFunction(pEffectInfo->interactionName1()));
 	}
+	else if (effectName == "crprod_gmm")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new OutTieFunction(pEffectInfo->interactionName1(), true));
+	}
 	else if (effectName == "crprodRecip")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
@@ -970,6 +1056,12 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			pSecondFunction->pFunction(sqrt);
 		}
 
+		if (pEffectInfo->internalEffectParameter() == 0)
+		{
+			pFirstFunction = new IntLogFunction(pFirstFunction);
+			pSecondFunction->pFunction(std::log);
+		}
+
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new DifferenceFunction(pFirstFunction, pSecondFunction));
 	}
@@ -1170,7 +1262,13 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new InStarFunction(pEffectInfo->interactionName1(),
-							(pEffectInfo->internalEffectParameter() >= 2)));
+							(pEffectInfo->internalEffectParameter() >= 2), false));
+	}
+	else if (effectName == "from_gmm")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new InStarFunction(pEffectInfo->interactionName1(),
+							(pEffectInfo->internalEffectParameter() >= 2), false, true));
 	}
 	else if (effectName == "fromMutual")
 	{
@@ -1178,6 +1276,11 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			new ReciprocatedTwoPathFunction(pEffectInfo->interactionName1(),
 							(pEffectInfo->internalEffectParameter() >= 2)));
 	}
+	else if (effectName == "fromAny")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new InStarFunction(pEffectInfo->interactionName1(), false, true));
+	}
 	else if (effectName == "to")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
@@ -1186,6 +1289,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 						pEffectInfo->variableName(),
 						FORWARD, FORWARD, pEffectInfo->internalEffectParameter()));
 	}
+	else if (effectName == "to_gmm")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+				new MixedTwoStepFunction(
+						pEffectInfo->interactionName1(),
+						pEffectInfo->variableName(),
+						FORWARD, FORWARD, pEffectInfo->internalEffectParameter(), true));
+	}
 	else if (effectName == "toBack") // formerly mixedInWX
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
@@ -1255,14 +1366,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	else if (effectName == "transTrip.EE")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedTwoStepFunction(pEffectInfo->variableName(), // not mixed, TwoStepFunction equivalent not implemented
+			new MixedTwoStepFunction(pEffectInfo->variableName(), // is not mixed, TwoStepFunction equivalent not implemented
 					pEffectInfo->variableName(),
 					EITHER, EITHER, 0));
 	}
 	else if (effectName == "transTrip.FE")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
-			new MixedTwoStepFunction(pEffectInfo->variableName(), // not mixed, TwoStepFunction equivalent not implemented
+			new MixedTwoStepFunction(pEffectInfo->variableName(), // is not mixed, TwoStepFunction equivalent not implemented
 					pEffectInfo->variableName(),
 					FORWARD, EITHER, 0));
 	}
@@ -1322,12 +1433,72 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 							pEffectInfo->variableName(),
 							pEffectInfo->internalEffectParameter(), false, false, true));
 	}
+	else if (effectName == "dist2OutInActIntn")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new DegreeDistance2Function(pEffectInfo->interactionName1(),
+							pEffectInfo->internalEffectParameter(), false, true, false));
+	}
 	else if (effectName == "sharedTo")
 	{
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 						new MixedThreeCyclesFunction(pEffectInfo->interactionName1(),
 							pEffectInfo->variableName(),
-							pEffectInfo->internalEffectParameter()));
+							pEffectInfo->internalEffectParameter(),
+							false));
+	}
+	else if (effectName == "sharedToU")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+						new MixedDyadicCovThreeCyclesFunction(pEffectInfo->interactionName1(),
+							pEffectInfo->variableName(),
+							pEffectInfo->interactionName2(),
+							pEffectInfo->internalEffectParameter(),
+							false));
+	}
+	else if (effectName == "avAlt.2M.tie")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+						new MixedThreeCyclesFunction(pEffectInfo->interactionName1(),
+							pEffectInfo->variableName(),
+							pEffectInfo->internalEffectParameter(),
+							true));
+	}
+	else if (effectName == "avAltU.2M.tie")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+						new MixedDyadicCovThreeCyclesFunction(pEffectInfo->interactionName1(),
+							pEffectInfo->variableName(),
+							pEffectInfo->interactionName2(),
+							pEffectInfo->internalEffectParameter(),
+							true));
+	}
+	else if (effectName == "inPopOutW")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new MixedThreePathFunction(pEffectInfo->variableName(),
+							pEffectInfo->interactionName1(),
+							pEffectInfo->internalEffectParameter(), true, false, false));
+	}
+	else if (effectName == "nDist2ActIntn")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new IndirectTiesFunction(pEffectInfo->interactionName1(),
+							pEffectInfo->internalEffectParameter(), false, true));
+	}
+	else if (effectName == "outOutDist2ActIntn")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new OutActDoubleDistance2Function(pEffectInfo->interactionName1(),
+							pEffectInfo->variableName(),
+							pEffectInfo->internalEffectParameter(), false, false));
+	}
+	else if (effectName == "avAlt.2M.tot")
+	{
+		pEffect = new GenericNetworkEffect(pEffectInfo,
+			new OutActDoubleDistance2Function(pEffectInfo->interactionName1(),
+							pEffectInfo->variableName(),
+							pEffectInfo->internalEffectParameter(), false, true));
 	}
 	else if (effectName == "inPopIntnX")
 	{
@@ -1373,17 +1544,13 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		string networkName = pEffectInfo->interactionName1();
 		string covariateName = pEffectInfo->interactionName2();
+		int parameter = int(round(pEffectInfo->internalEffectParameter()));
 		AlterFunction * pChangeFunction =
 			new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, false);
+									true, false, parameter, false);
 		AlterFunction * pStatisticFunction =
 			new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, true);
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
+									true, false, parameter, true);
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			pChangeFunction, pStatisticFunction);
 	}
@@ -1391,17 +1558,13 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		string networkName = pEffectInfo->interactionName1();
 		string covariateName = pEffectInfo->interactionName2();
+		int parameter = int(round(pEffectInfo->internalEffectParameter()));
 		AlterFunction * pChangeFunction =
 			new EgoFunction(new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, false));
+									true, false, parameter, false));
 		AlterFunction * pStatisticFunction =
 			new EgoFunction(new SameCovariateInTiesFunction(networkName, covariateName,
-									true, false, true));
-		if (pEffectInfo->internalEffectParameter() == 2)
-		{
-			pChangeFunction = new IntSqrtFunction(pChangeFunction);
-			pStatisticFunction = new IntSqrtFunction(pStatisticFunction);
-		}
+									true, false, parameter, true));
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			pChangeFunction, pStatisticFunction);
 	}
@@ -1457,14 +1620,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		string covariateName = pEffectInfo->interactionName2();
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			new ConditionalFunction(new EqualCovariatePredicate(covariateName),
-				new InStarFunction(networkName, false),
+				new InStarFunction(networkName, false, false),
 				0),
 			new ConditionalFunction(
 				new MissingCovariatePredicate(covariateName),
 				0,
 				new ConditionalFunction(
 					new EqualCovariatePredicate(covariateName),
-					new InStarFunction(networkName, false),
+					new InStarFunction(networkName, false, false),
 					0)));
 	}
 	else if (effectName == "homCovNetNet")
@@ -1883,6 +2046,13 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 			pEffect = new OutdegreeContinuousEffect(pEffectInfo, true);
 		}
 	}
+    else if (effectName == "outInBalance")
+    {
+        if (pContinuousData)
+        {
+            pEffect = new OutIndegreeBalanceContinuousEffect(pEffectInfo);
+        }
+    }
 	else if (effectName == "isolate")
 	{
 		pEffect = new IsolateEffect(pEffectInfo, true);
@@ -2055,6 +2225,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new AverageSimilarityInDist2Effect(pEffectInfo, false);
 	}
+    else if (effectName == "avSimVarAlt")
+    {
+        pEffect = new VarianceAlterSimilarityEffect(pEffectInfo, true, false, false);
+    }
 	else if (effectName == "avAlt")
 	{
 		if (pContinuousData)
@@ -2063,8 +2237,8 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		}
 		else
 		{
-		pEffect = new AverageAlterEffect(pEffectInfo, true, false);
-	}
+			pEffect = new AverageAlterEffect(pEffectInfo, true, false);
+		}
 	}
 	else if (effectName == "avAlt_gmm")
 	{
@@ -2168,6 +2342,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new AverageAlterInDist2Effect(pEffectInfo, false, true);
 	}
+    else if (effectName == "varAlt")
+    {
+        pEffect = new VarianceAlterEffect(pEffectInfo);
+    }
 	else if (effectName == "behDenseTriads")
 	{
 		pEffect = new DenseTriadsBehaviorEffect(pEffectInfo);
