@@ -43,7 +43,7 @@ protected:
 
 private:
 	// Indicates if the square root of degrees must be used
-	bool lroot;
+	bool lroot {};
 
 	// Lookup table for fast square root calculations
 	SqrtTable * lsqrtTable;
