@@ -27,7 +27,7 @@ class EgoInDegreeFunction: public OneModeNetworkAlterFunction, IntAlterFunction
 public:
 	EgoInDegreeFunction(std::string networkName);
 
-	virtual double value(int alter);
+	virtual double value(int alter) const;
 	virtual int intValue(int alter);
 };
 
