@@ -13,6 +13,7 @@
 #ifndef GENERICNETWORKEFFECT_H_
 #define GENERICNETWORKEFFECT_H_
 
+#include <string>
 #include "model/effects/NetworkEffect.h"
 
 namespace siena
@@ -35,6 +36,12 @@ public:
 		State * pState,
 		int period,
 		Cache * pCache);
+	virtual void initialize(const Data * pData,
+			State * pState, 
+			State * pSimulatedState, 
+			int period, 
+			Cache * pCache); 
+// The pSimulatedState is used for the GMoM.
 	virtual void preprocessEgo(int ego);
 
 	virtual double calculateContribution(int alter) const;
@@ -45,6 +52,7 @@ protected:
 private:
 	AlterFunction * lpEffectFunction;
 	AlterFunction * lpStatisticFunction;
+	std::string lEffectType {};
 };
 
 }
