@@ -40,12 +40,17 @@ public MixedNetworkAlterFunction, IntAlterFunction
 {
 public:
 	MixedTwoStepFunction(std::string firstNetworkName, std::string secondNetworkName,
-						Direction firstDirection, Direction secondDirection, double par);
+				Direction firstDirection, Direction secondDirection, double par);
+	MixedTwoStepFunction(std::string firstNetworkName, std::string secondNetworkName,
+				Direction firstDirection, Direction secondDirection, 
+				double par, const bool simulatedState);
 
 	virtual void initialize(const Data * pData,
 		State * pState,
 		int period,
 		Cache * pCache);
+	virtual void initialize(const Data * pData,
+		State * pState, State * pSimulatedState, int period, Cache * pCache);
 
 	virtual double value(int alter) const;
 	virtual int intValue(int alter);
