@@ -31,8 +31,8 @@ public:
 	virtual double value(int alter) const;
 
 private:
-	bool lsame;
-	bool lexcludeMissing;
+	bool lsame {};
+	bool lexcludeMissing {};
 };
 
 }
