@@ -14,6 +14,7 @@
 #include <string>
 #include <cmath>
 #include <R_ext/Error.h>
+#include <memory>
 #include "MLSimulation.h"
 
 #include <Rinternals.h>
@@ -726,38 +727,30 @@ bool MLSimulation::move()
 
 	////CHOOSING MINISTEPB
 
-	double * newReciprocalRate = new double[intLength];
-	double * newOptionSetProbability = new double[intLength];
-	double * newChoiceProbability = new double[intLength];
+	// Replace raw arrays with std::vector for automatic memory management
+	std::vector<double> newReciprocalRate(intLength);
+	std::vector<double> newOptionSetProbability(intLength);
+	std::vector<double> newChoiceProbability(intLength);
 
-	double * reciprocalRateA = 0;
-	double * optionSetProbabilityA = 0;
-	double * choiceProbabilityA = 0;
+	std::vector<double> reciprocalRateA;
+	std::vector<double> optionSetProbabilityA;
+	std::vector<double> choiceProbabilityA;
 
 	if (this->pModel()->localML())
 	{
-		reciprocalRateA = new double[intLength];
-		optionSetProbabilityA = new double[intLength];
-		choiceProbabilityA = new double[intLength];
+		reciprocalRateA.resize(intLength);
+		optionSetProbabilityA.resize(intLength);
+		choiceProbabilityA.resize(intLength);
 	}
 
-	bool * updateProb = new bool[intLength];
-	double * pi = new double[intLength];
+	std::vector<bool> updateProb(intLength, false);
+	std::vector<double> pi(intLength, 0.0);
 
 	pi[0] = 1;
 	piCount = 0;
 
-	// SETTING PI AND UPDATE
-	for (int k=0;k < intLength;k++)
-	{
-		updateProb[k] = false;
-	}
-	for (int k=1;k < intLength;k++)
-	{
-		pi[k] = 0;
-	}
-
-	MiniStep * pMiniStepAReverse = pMiniStepA->createReverseMiniStep();
+	// Use std::unique_ptr for automatic memory management of pMiniStepAReverse
+	std::unique_ptr<MiniStep> pMiniStepAReverse(pMiniStepA->createReverseMiniStep());
 	pMiniStepC = pFirst;
 
 	// CREATING VARIABLES, EGOS AND ALTERS FOR MiniSteps A AND C
@@ -910,7 +903,7 @@ bool MLSimulation::move()
 		}
 	}
 
-	delete pMiniStepAReverse;
+	// We don't need to delete pMiniStepAReverse anymore as it's managed by unique_ptr
 
 	// Making pi sum to 1
 	double piSum = 0;
@@ -923,7 +916,7 @@ bool MLSimulation::move()
 		pi[k] /= piSum;
 	}
 
-	int miniStepChoice = nextIntWithProbabilities(intLength, pi);
+	int miniStepChoice = nextIntWithProbabilities(intLength, pi.data());
 
 	// Will give no change
 		if (miniStepChoice == positionA)
@@ -1103,21 +1096,12 @@ bool MLSimulation::move()
 
 	this->recordOutcome(*pMiniStepA, accept, MOVE, false);
 
-	delete[] pi;
-	delete[] updateProb;
-	if (this->pModel()->localML())
-	{
-		delete[] choiceProbabilityA;
-		delete[] optionSetProbabilityA;
-		delete[] reciprocalRateA;
-	}
-	delete[] newChoiceProbability;
-	delete[] newOptionSetProbability;	
-	delete[] newReciprocalRate;
-	
+	// No need to delete arrays anymore as they're managed by std::vector
+
 	return accept;
 }
 
+
 /**
  * Implements the MH_permute Metropolis-Hastings step.
  */
@@ -1591,85 +1575,8 @@ bool MLSimulation::insertPermute(int c0)
 			// otherwise, 2 unless preceding or succeeding ministeps to A or B
 			// are the same.
 
-			// 			int newConsecutiveCancelingPairCount =
-			// 				this->pChain()->consecutiveCancelingPairCount() + 1;
-
-			// 			if (this->pChain()->nextMiniStepForOption(
-			// 					*(pLeftMiniStep->pOption()), this->pChain()->pFirst()))
-			// 			{
-			// 				newConsecutiveCancelingPairCount += 1;
-			// 				if (pLeftMiniStep->networkMiniStep())
-			// 				{
-			// 					if (pMiniStepA->pPrevious()->pOption() ==
-			// 						pLeftMiniStep->pOption())
-			// 					{
-			// 						newConsecutiveCancelingPairCount--;
-			// 					}
-			// 					if (pMiniStepB->pOption() ==
-			// 						pLeftMiniStep->pOption())
-			// 					{
-			// 						newConsecutiveCancelingPairCount--;
-			// 					}
-			// 				}
-			// 				else // behavior miniStep
-			// 				{
-
-			// 					BehaviorChange * pPreviousMiniStep =
-			// 						dynamic_cast<BehaviorChange *>
-			// 						(this->pChain()->nextMiniStepForOption(
-			// 							*(pLeftMiniStep->pOption()), pMiniStepA));
-			// 					if (pPreviousMiniStep)
-			// 					{
-			// 						pPreviousMiniStep = dynamic_cast<BehaviorChange *>
-			// 							(pPreviousMiniStep->pPreviousWithSameOption());
-			// 					}
-			// 					BehaviorChange * pNextMiniStep =
-			// 						dynamic_cast<BehaviorChange *>
-			// 						(this->pChain()->nextMiniStepForOption(
-			// 							*(pLeftMiniStep->pOption()), pMiniStepB));
-			// 					BehaviorChange * pThisMiniStep =
-			// 						dynamic_cast <BehaviorChange *>
-			// 						(pLeftMiniStep);
-			// 					int d0 = pThisMiniStep->difference();
-			// 					int dMinus = 0;
-			// 					int dPlus = 0;
-			// 					if (pPreviousMiniStep)
-			// 					{
-			// 						dPlus = pPreviousMiniStep->difference();
-			// 					}
-			// 					if (pNextMiniStep)
-			// 					{
-			// 						dMinus = pNextMiniStep->difference();
-			// 					}
-			// 					if (pPreviousMiniStep == pMiniStepA->pPrevious() ||
-			// 						dMinus == d0)
-			// 					{
-			// 						newConsecutiveCancelingPairCount--;
-			// 					}
-			// 					if (pNextMiniStep == pMiniStepB ||
-			// 						dPlus == d0)
-			// 					{
-			// 						newConsecutiveCancelingPairCount--;
-			// 					}
-			// 				}
-			// 			}
-			// 			Rf_PrintValue(getChainDF(*(this->pChain())));
-			// 			this->pChain()->printConsecutiveCancelingPairs();
 			this->pChain()->insertBefore(pLeftMiniStep, pMiniStepA);
 			this->pChain()->insertBefore(pRightMiniStep, pMiniStepB);
-			// 			Rf_PrintValue(getChainDF(*(this->pChain())));
-			// 			this->pChain()->printConsecutiveCancelingPairs();
-			// 			if (newConsecutiveCancelingPairCount !=
-			// 				this->pChain()->consecutiveCancelingPairCount())
-			// 			{
-			// 				Rprintf("ins diff %d %d \n",newConsecutiveCancelingPairCount,
-			// 					this->pChain()->consecutiveCancelingPairCount() );
-			// 			Rf_PrintValue(getMiniStepDF(*pMiniStepA));
-			//  				Rf_PrintValue(getMiniStepDF(*pMiniStepB));
-			//  				Rf_PrintValue(getMiniStepDF(*pLeftMiniStep));
-			//  				Rf_PrintValue(getMiniStepDF(*pRightMiniStep));
-			//  				Rf_error("time to stop");
-			//  			}
 
 			pr1 =
 			    (1 -
@@ -2068,89 +1975,11 @@ bool MLSimulation::deletePermute(int c0)
 			// otherwise, 2 unless preceding or succeeding ministeps to A or B
 			// are the same.
 
-			// 			Rf_PrintValue(getChainDF(*(this->pChain())));
-			// 			this->pChain()->printConsecutiveCancelingPairs();
-
-			// 			int newConsecutiveCancelingPairCount =
-			//  				this->pChain()->consecutiveCancelingPairCount() - 1;
-
-			// 			if (this->pChain()->nextMiniStepForOption(
-			// 					*(pMiniStepA->pOption()), this->pChain()->pFirst()))
-			// 			{
-			// 				newConsecutiveCancelingPairCount -= 1;
-			// 				if (pMiniStepA->networkMiniStep())
-			// 				{
-			// 					if (pMiniStepA->pPrevious()->pOption() ==
-			// 						pMiniStepA->pOption())
-			// 					{
-			// 						newConsecutiveCancelingPairCount++;
-			// 					}
-			// 					if (pMiniStepB->pNext()->pOption() ==
-			// 						pMiniStepB->pOption())
-			// 					{
-			// 						newConsecutiveCancelingPairCount++;
-			// 					}
-			// 				}
-			// 				else // behavior miniStep
-			// 				{
-
-			// 					BehaviorChange * pPreviousMiniStep =
-			// 						dynamic_cast<BehaviorChange *>
-			// 						(this->pChain()->nextMiniStepForOption(
-			// 							*(pMiniStepA->pOption()), pMiniStepA));
-			// 					if (pPreviousMiniStep)
-			// 					{
-			// 						pPreviousMiniStep =
-			// 						dynamic_cast<BehaviorChange *>
-			// 							(pPreviousMiniStep->pPreviousWithSameOption());
-			// 					}
-			// 					BehaviorChange * pNextMiniStep =
-			// 						dynamic_cast<BehaviorChange *>
-			// 						(this->pChain()->nextMiniStepForOption(
-			// 							*(pMiniStepB->pOption()), pMiniStepB));
-			// 					BehaviorChange * pThisMiniStep =
-			// 						dynamic_cast <BehaviorChange *>
-			// 						(pMiniStepA);
-			// 					int d0 = pThisMiniStep->difference();
-			// 					int dMinus = 0;
-			// 					int dPlus = 0;
-			// 					if (pPreviousMiniStep)
-			// 					{
-			// 						dPlus = pPreviousMiniStep->difference();
-			// 					}
-			// 					if (pNextMiniStep)
-			// 					{
-			// 						dMinus = pNextMiniStep->difference();
-			// 					}
-			// 					if (pPreviousMiniStep == pMiniStepA->pPrevious() ||
-			// 						dMinus == d0)
-			// 					{
-			// 						newConsecutiveCancelingPairCount++;
-			// 					}
-			// 					if (pNextMiniStep == pMiniStepB->pNext() ||
-			// 						dPlus == d0)
-			// 					{
-			// 						newConsecutiveCancelingPairCount++;
-			// 					}
-			// 				}
-			// 			}
 			// insert and delete
 			MiniStep * pAfterA = pMiniStepA->pNext();
 			this->pChain()->remove(pMiniStepA);
 			MiniStep * pAfterB = pMiniStepB->pNext();
 			this->pChain()->remove(pMiniStepB);
-			// 			if (newConsecutiveCancelingPairCount !=
-			// 				this->pChain()->consecutiveCancelingPairCount())
-			// 			{
-			// 			this->pChain()->printConsecutiveCancelingPairs();
-			// 				Rprintf("diff %d %d \n",newConsecutiveCancelingPairCount,
-			// 					this->pChain()->consecutiveCancelingPairCount() );
-			// 				Rf_PrintValue(getMiniStepDF(*pMiniStepA));
-			// 				Rf_PrintValue(getMiniStepDF(*pMiniStepB));
-			// 				Rf_PrintValue(getMiniStepDF(*pAfterA));
-			// 				Rf_PrintValue(getMiniStepDF(*pAfterB));
-			// 				Rf_error("time to stop");
-			// 			}
 			this->pChain()->insertBefore(pMiniStepA, pAfterA);
 			this->pChain()->insertBefore(pMiniStepB, pAfterB);
 
@@ -2613,7 +2442,6 @@ bool MLSimulation::insertMissing()
 	return accept;
 }
 
-
 /**
  * Implements the MH_DelMis Metropolis-Hastings step.
  */
@@ -2895,9 +2723,9 @@ bool MLSimulation::deleteMissing()
 		delete pMiniStepA;
 	}
 
-	delete[] newReciprocalRate;
-	delete[] newOptionSetProbability;
 	delete[] newChoiceProbability;
+	delete[] newOptionSetProbability;
+	delete[] newReciprocalRate;
 
 	return accept;
 }
