@@ -40,6 +40,10 @@ SEXP mlPeriod(SEXP DERIV, SEXP DATAPTR,
 
 SEXP clearStoredChains(SEXP MODELPTR, SEXP KEEP, SEXP GROUPPERIOD);
 
+SEXP getChainProbabilities(SEXP DATAPTR, SEXP MODELPTR,
+	SEXP GROUP, SEXP PERIOD, SEXP INDEX, SEXP EFFECTSLIST, SEXP THETA,
+	SEXP GETSCORES);
+
 } // extern "C"
 
 #endif /*SIENA07MODELS_H_*/
