@@ -438,7 +438,6 @@ SEXP effects(SEXP RpData, SEXP EFFECTSLIST)
 			R_NilValue,
 			R_NilValue));
 
-
 	/* ans will be the return value */
 	SEXP ans;
 	PROTECT(ans = Rf_allocVector(VECSXP, 2));
@@ -704,32 +703,32 @@ SEXP getTargetActorStatistics(SEXP dataptr, SEXP modelptr, SEXP effectslist, SEX
 	{
 		SET_VECTOR_ELT(altStats, group, Rf_allocVector(VECSXP, (*pGroupData)[group]->observationCount()));
 		for (int p = 0; p < (*pGroupData)[group]->observationCount(); p++)
-	{
-			SET_VECTOR_ELT(VECTOR_ELT(altStats,group), p, Rf_allocVector(VECSXP, objEffects));
-	}
+		{
+			SET_VECTOR_ELT(VECTOR_ELT(altStats, group), p, Rf_allocVector(VECSXP, objEffects));
+		}
 	}
 
 	for (size_t group = 0; group < nGroups; group++)
 	{
 		Data * pData = (*pGroupData)[group];
 		for (int period = 0; period < pData->observationCount() - 1; period++)
-	{
+		{
 			State state(pData, period + 1);
 			StatisticCalculator calculator(pData, pModel, &state, period, true);
 			int actors = pData->rDependentVariableData()[0]->n();
 			vector<double *> actorStatistics;
 			getActorStatistics(effectslist, &calculator, &actorStatistics);
 			for (unsigned e = 0; e < actorStatistics.size(); e++)
-		 {
+			{
 				SEXP actorStatsValues;
-				PROTECT(actorStatsValues = Rf_allocVector(REALSXP,actors));
+				PROTECT(actorStatsValues = Rf_allocVector(REALSXP, actors));
 				double * astats = REAL(actorStatsValues);
 				for (int i = 0; i < actors; i++)
-			{
+				{
 					astats[i] = actorStatistics.at(e)[i];
 				}
-				SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(altStats,group), period+1), e, actorStatsValues);
-				UNPROTECT(1);
+				SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(altStats, group), period+1), e, actorStatsValues);
+				UNPROTECT(1);         
 			}
 		}
 	}
@@ -737,6 +736,7 @@ SEXP getTargetActorStatistics(SEXP dataptr, SEXP modelptr, SEXP effectslist, SEX
 	return altStats;
 }
 
+
 SEXP getTargetsChangeContributions(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST, SEXP PARALLELRUN)
 {
 	vector<Data *> * pGroupData = (vector<Data *> *) R_ExternalPtrAddr(DATAPTR);
@@ -755,9 +755,9 @@ SEXP getTargetsChangeContributions(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST
 	for (size_t group = 0; group < nGroups; group++)
 	{
 		SET_VECTOR_ELT(altStats, group, Rf_allocVector(VECSXP, (*pGroupData)[group]->observationCount()));
-			for (int p = 0; p < (*pGroupData)[group]->observationCount(); p++)
+		for (int p = 0; p < (*pGroupData)[group]->observationCount(); p++)
 		{
-			SET_VECTOR_ELT(VECTOR_ELT(altStats,group), p, Rf_allocVector(VECSXP,objEffects));
+			SET_VECTOR_ELT(VECTOR_ELT(altStats, group), p, Rf_allocVector(VECSXP, objEffects));
 		}
 	}
 
@@ -770,15 +770,15 @@ SEXP getTargetsChangeContributions(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST
 			State State (pData, period + 1);
 			// TODO altStats[0] == altStats[1] ??
 			StatisticCalculator calculator(pData, pModel, &State, period, false, true);
-			vector<vector<double * > > changeContributions;
+			vector<vector<double *>> changeContributions;
 			getChangeContributionStatistics(EFFECTSLIST, &calculator, &changeContributions);
 			int actors = pData->rDependentVariableData()[0]->n();
-			for(unsigned e = 0; e < changeContributions.size(); e++)
+			for (unsigned e = 0; e < changeContributions.size(); e++)
 			{
-				SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(altStats,group), period+1),
-								e, Rf_allocVector(VECSXP,actors));
+				SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(altStats, group), period+1),
+								e, Rf_allocVector(VECSXP, actors));
 				int choices;
-				if (strcmp(CHAR(STRING_ELT(NETWORKTYPES,e)), "behavior") == 0)
+				if (strcmp(CHAR(STRING_ELT(NETWORKTYPES, e)), "behavior") == 0)
 				{
 					choices = 3;
 				}
@@ -787,49 +787,51 @@ SEXP getTargetsChangeContributions(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST
 					choices = actors; // will not work for bipartite
 					// But I did not find a convenient way to get knowledge of m() to here
 				}
-				for(int actor = 0; actor < actors; actor++)
+				for (int actor = 0; actor < actors; actor++)
 				{
 					SEXP actorsVal = PROTECT(Rf_allocVector(REALSXP, choices));
 					double * d = REAL(actorsVal);
-					for(int i = 0; i< Rf_length(actorsVal); i++)
+					for (int i = 0; i < Rf_length(actorsVal); i++)
 					{
-						d[i]=changeContributions.at(e).at(actor)[i];
+						d[i] = changeContributions.at(e).at(actor)[i];
 					}
 					SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(altStats, group), period+1), e), 
 								actor, actorsVal);
-					UNPROTECT(1);
+					UNPROTECT(1);         
 				}
 			}
 		}
+		
+        // Handle period 0 separately
 		State State (pData, 0);
 		StatisticCalculator calculator(pData, pModel, &State, 0, false, true);
-			vector<vector<double * > > changeContributions;
+		vector<vector<double *>> changeContributions;
 		getChangeContributionStatistics(EFFECTSLIST, &calculator, &changeContributions);
 		int actors = pData->rDependentVariableData()[0]->n();
-		for(unsigned e = 0; e < changeContributions.size(); e++)
+		for (unsigned e = 0; e < changeContributions.size(); e++)
 		{
 			SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(altStats, group), 0),
 				e, Rf_allocVector(VECSXP, actors));
 			int choices;
-			if (strcmp(CHAR(STRING_ELT(NETWORKTYPES,e)), "behavior") == 0)
+			if (strcmp(CHAR(STRING_ELT(NETWORKTYPES, e)), "behavior") == 0)
 			{
 				choices = 3;
 			}
 			else
 			{						
-					choices = actors; // will not work for bipartite
+				choices = actors; // will not work for bipartite
 			}
-			for(int actor = 0; actor < actors; actor++)
+			for (int actor = 0; actor < actors; actor++)
 			{
 				SEXP actorsVal = PROTECT(Rf_allocVector(REALSXP, choices));
 				double * d = REAL(actorsVal);
-				for(int i = 0; i< Rf_length(actorsVal); i++)
+				for (int i = 0; i < Rf_length(actorsVal); i++)
 				{
-					d[i]=changeContributions.at(e).at(actor)[i];
+					d[i] = changeContributions.at(e).at(actor)[i];
 				}
 				SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(altStats, group), 0), e), 
 						actor, actorsVal);
-				UNPROTECT(1);
+				UNPROTECT(1);     
 			}
 		}
 	}
@@ -837,6 +839,8 @@ SEXP getTargetsChangeContributions(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST
 	return altStats;
 }
 
+
+
 /**
  *  Gets target values relative to the input data
  */
@@ -847,7 +851,7 @@ SEXP getTargets(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST,
 	// select alternative result type
 	int returnActorStatistics = sexp_to_int(RETURNACTORSTATISTICS, 0);
 	int returnStaticChangeContributions = sexp_to_int(RETURNSTATICCHANGECONTRIBUTIONS, 0);
-	if(returnActorStatistics + returnStaticChangeContributions >= 2)
+	if (returnActorStatistics + returnStaticChangeContributions >= 2)
 	{
 		Rf_error("returnActorStatistics and returnStaticChangeContributions are mutually exclusive");
 	}
@@ -922,18 +926,20 @@ SEXP getTargets(SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST,
 			//			group, pData, &Simulation,
 			//&statistic, &score);
 			//	Rprintf("%f %f \n",statistic[1], statistic[2]);
-			/* fill up matrices for  return value list */
+			/* fill up matrices for return value list */
 			int iii = (periodFromStart - 1) * nEffects;
 			for (unsigned effectNo = 0; effectNo < statistic.size(); effectNo++)
-	{
+			{
 				rfra[iii + effectNo] = statistic[effectNo];
 			}
 		}
 	}
 	UNPROTECT(1);
-		return fra;
+	return fra;
 }
 
+
+
 /**
  * Sets up a minimal chain and does pre burnin and burnin.
  * Processes a complete set of data objects, creating a chain for each
@@ -1058,9 +1064,9 @@ SEXP mlMakeChains(SEXP DATAPTR, SEXP MODELPTR,
 				pMLSimulation->rVariables();
 			int numberVariables = rVariables.size();
 
-			SEXP accepts1 = PROTECT(Rf_allocMatrix(INTSXP, numberVariables, 9));
-			SEXP rejects1 = PROTECT(Rf_allocMatrix(INTSXP, numberVariables, 9));
-			SEXP aborts1 = PROTECT(Rf_allocVector(INTSXP, 9));
+			SEXP accepts1 = PROTECT(Rf_allocMatrix(INTSXP, numberVariables, NBRTYPES));
+			SEXP rejects1 = PROTECT(Rf_allocMatrix(INTSXP, numberVariables, NBRTYPES));
+			SEXP aborts1 = PROTECT(Rf_allocVector(INTSXP, NBRTYPES));
 			int * iaccepts = INTEGER(accepts1);
 			int * irejects = INTEGER(rejects1);
 			int * iaborts = INTEGER(aborts1);
